@@ -1,20 +1,9 @@
 //  -*- c-basic-offset:4; indent-tabs-mode:nil -*-
-/* This file is part of the KDE libraries
-   Copyright (C) 2002-2003 Alexander Kellett <lypanov@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2002-2003 Alexander Kellett <lypanov@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kbookmarkimporter_opera.h"
@@ -22,7 +11,7 @@
 
 #include <QFileDialog>
 #include "kbookmarks_debug.h"
-#include <qtextcodec.h>
+#include <QTextCodec>
 #include <QApplication>
 
 #include <qplatformdefs.h>
@@ -52,9 +41,10 @@ void KOperaBookmarkImporter::parseOperaBookmarks()
 
         // first two headers lines contain details about the format
         if (lineno <= 2) {
-            if (line.toLower().startsWith(QLatin1String("options:"))) {
-                foreach (const QString &ba, line.mid(8).split(',')) {
-                    const int pos = ba.indexOf('=');
+            if (line.startsWith(QLatin1String("options:"), Qt::CaseInsensitive)) {
+                const auto lst = line.mid(8).split(QLatin1Char(','));
+                for (const QString &ba : lst) {
+                    const int pos = ba.indexOf(QLatin1Char('='));
                     if (pos < 1) {
                         continue;
                     }
@@ -85,7 +75,7 @@ void KOperaBookmarkImporter::parseOperaBookmarks()
         } else {
             // data block line
             QString tag;
-            if (tag = '#', line.startsWith(tag)) {
+            if (tag = QStringLiteral("#"), line.startsWith(tag)) {
                 type = line.remove(0, tag.length());
             } else if (tag = QStringLiteral("NAME="), line.startsWith(tag)) {
                 name = line.remove(0, tag.length());
@@ -114,11 +104,12 @@ void KOperaBookmarkImporterImpl::parse()
 
 QString KOperaBookmarkImporterImpl::findDefaultLocation(bool saving) const
 {
+    const QString operaHomePath = QDir::homePath() + QLatin1String("/.opera");
     return saving ? QFileDialog::getSaveFileName(QApplication::activeWindow(), QString(),
-            QDir::homePath() + "/.opera",
+            operaHomePath,
             tr("Opera Bookmark Files (*.adr)"))
            : QFileDialog::getOpenFileName(QApplication::activeWindow(), QString(),
-                                          QDir::homePath() + "/.opera",
+                                          operaHomePath,
                                           tr("*.adr|Opera Bookmark Files (*.adr)"));
 }
 
@@ -134,9 +125,9 @@ public:
         return m_string;
     }
 private:
-    void visit(const KBookmark &) Q_DECL_OVERRIDE;
-    void visitEnter(const KBookmarkGroup &) Q_DECL_OVERRIDE;
-    void visitLeave(const KBookmarkGroup &) Q_DECL_OVERRIDE;
+    void visit(const KBookmark &) override;
+    void visitEnter(const KBookmarkGroup &) override;
+    void visitLeave(const KBookmarkGroup &) override;
 private:
     QString m_string;
     QTextStream m_out;
@@ -144,32 +135,36 @@ private:
 
 OperaExporter::OperaExporter() : m_out(&m_string, QIODevice::WriteOnly)
 {
-    m_out << "Opera Hotlist version 2.0" << endl;
-    m_out << "Options: encoding = utf8, version=3" << endl;
+    m_out << "Opera Hotlist version 2.0\n";
+    m_out << "Options: encoding = utf8, version=3\n";
+    m_out.flush();
 }
 
 void OperaExporter::visit(const KBookmark &bk)
 {
     // qCDebug(KBOOKMARKS_LOG) << "visit(" << bk.text() << ")";
-    m_out << "#URL" << endl;
-    m_out << "\tNAME=" << bk.fullText() << endl;
-    m_out << "\tURL=" << bk.url().toString().toUtf8() << endl;
-    m_out << endl;
+    m_out << "#URL\n";
+    m_out << "\tNAME=" << bk.fullText() << '\n';
+    m_out << "\tURL=" << bk.url().toString().toUtf8() << '\n';
+    m_out << '\n';
+    m_out.flush();
 }
 
 void OperaExporter::visitEnter(const KBookmarkGroup &grp)
 {
     // qCDebug(KBOOKMARKS_LOG) << "visitEnter(" << grp.text() << ")";
-    m_out << "#FOLDER" << endl;
-    m_out << "\tNAME=" << grp.fullText() << endl;
-    m_out << endl;
+    m_out << "#FOLDER\n";
+    m_out << "\tNAME=" << grp.fullText() << '\n';
+    m_out << '\n';
+    m_out.flush();
 }
 
 void OperaExporter::visitLeave(const KBookmarkGroup &)
 {
     // qCDebug(KBOOKMARKS_LOG) << "visitLeave()";
-    m_out << "-" << endl;
-    m_out << endl;
+    m_out << "-\n";
+    m_out << '\n';
+    m_out.flush();
 }
 
 void KOperaBookmarkExporterImpl::write(const KBookmarkGroup &parent)
@@ -178,7 +173,7 @@ void KOperaBookmarkExporterImpl::write(const KBookmarkGroup &parent)
     QString content = exporter.generate(parent);
     QFile file(m_fileName);
     if (!file.open(QIODevice::WriteOnly)) {
-        qCCritical(KBOOKMARKS_LOG) << "Can't write to file " << m_fileName << endl;
+        qCCritical(KBOOKMARKS_LOG) << "Can't write to file " << m_fileName;
         return;
     }
     QTextStream fstream(&file);
